@@ -4,25 +4,30 @@ use super::*;
 
 pub(crate) mod ca;
 pub(crate) mod crl;
-pub(crate) mod vcek;
+pub(crate) mod hashsticks;
+pub(crate) mod vek;
 use anyhow::Result;
 
 #[derive(Subcommand)]
 pub enum Fetch {
     /// Fetches the VCEK from the KDS
-    Vcek(vcek::Vcek),
+    Vek(vek::Vek),
 
     /// Fetches the CA from the KDS
     Ca(ca::Ca),
 
     /// Fetches the CRL from the KDS
     Crl(crl::Crl),
+
+    /// Fetches the VLEK hashsticks from the KDS
+    Hashsticks(hashsticks::Hashsticks),
 }
 
 pub fn cmd(fetch: Fetch) -> Result<()> {
     match fetch {
-        Fetch::Vcek(vcek) => vcek::cmd(vcek),
+        Fetch::Vek(vek) => vek::cmd(vek),
         Fetch::Ca(ca) => ca::cmd(ca),
         Fetch::Crl(crl) => crl::cmd(crl),
+        Fetch::Hashsticks(hashsticks) => hashsticks::cmd(hashsticks),
     }
 }
