@@ -2,7 +2,7 @@
 
 use super::*;
 
-use cert::fetch::vcek::vcek_url;
+use cert::{fetch::hashsticks::vlek_hashsticks_url, fetch::vek::vek_url, Endorsement};
 
 #[derive(Subcommand)]
 pub enum Show {
@@ -18,6 +18,12 @@ pub enum Show {
     /// Show the VCEK DER download URL
     VcekUrl,
 
+    /// Show the VLEK DER download URL
+    VlekUrl,
+
+    /// Show the VLEK hashsticks download URL
+    HashsticksURL,
+
     /// Show the platform's firmware version
     Version,
 }
@@ -40,10 +46,12 @@ pub fn cmd(show: Show) -> Result<()> {
             status.reported_tcb_version, status.platform_tcb_version
         ),
         Show::VcekUrl => {
-            let url = vcek_url()?;
+            let url = vek_url(Endorsement::Vcek)?;
 
             println!("{}", url);
         }
+        Show::VlekUrl => println!("{}", vek_url(Endorsement::Vlek)?),
+        Show::HashsticksURL => println!("{}", vlek_hashsticks_url()?),
         Show::Version => println!("{}.{}", status.version.0, status.version.1),
     }
 
